============================================================
Translation of homologs (:mod:`gene.homology`)
============================================================

.. py:currentmodule:: Orange.bio.gene.homology

This module is an interface to `NCBI HomoloGene <http://www.ncbi.nlm.nih.gov/homologene/>`_.

.. autofunction::  Orange.bio.gene.homology.all_genes

.. autofunction::  Orange.bio.gene.homology.homologs

.. autofunction::  Orange.bio.gene.homology.homolog

.. autofunction::  Orange.bio.gene.homology.orthologs

.. autofunction::  Orange.bio.gene.homology.all_genes_inParanoid

Examples
--------

Mapping homologs from yeast to human:

.. literalinclude:: code/homology-yeast-to-human.py

